import { Autocomplete, TextField } from "@mui/material";
import { NWFilter } from "../../api/NWFilterApi";
import { NWFilterItem } from "../nwfilter/NWFilterItem";

export function NWFilterSelectInput(p: {
  editable: boolean;
  label?: string;
  nwfilters: NWFilter[];
  value?: string;
  onChange?: (name?: string) => void;
  canBeNull: boolean;
}): React.ReactElement {
  const selectedValue = p.nwfilters.find((o) => o.name === p.value);
  if (!p.editable && !selectedValue) return <></>;

  if (selectedValue)
    return (
      <NWFilterItem
        value={selectedValue}
        onDelete={p.editable ? () => p.onChange?.(undefined) : undefined}
      />
    );

  return (
    <Autocomplete
      disablePortal
      options={[...(p.canBeNull ? [undefined] : []), ...p.nwfilters]}
      getOptionLabel={(o) => o?.name ?? "Unspecified"}
      value={selectedValue}
      renderInput={(params) => (
        <TextField {...params} variant="standard" label={p.label} />
      )}
      renderOption={(_props, option, _state) => (
        <NWFilterItem
          onClick={() => p.onChange?.(option?.name)}
          value={option}
        />
      )}
    />
  );
}
